# Intentional - Core package

[![PyPI - Version](https://img.shields.io/pypi/v/intentional-core.svg)](https://pypi.org/project/intentional-core)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/intentional-core.svg)](https://pypi.org/project/intentional-core)

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install intentional-core
```

## License

`intentional` is distributed under the terms of the [AGPL](LICENSE.txt) license.
